@@ -1,4 +1,4 @@
-/* $Id: netload.c,v 1.12 2003/10/20 15:19:36 hadess Exp $ */
+/* $Id: netload.c,v 1.14 2004/06/09 18:52:20 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -22,6 +22,8 @@
 */
 
 #include <locale.h>
+#include <libintl.h>
+#include <stdio.h>
 
 #include <glibtop.h>
 #include <glibtop/open.h>
@@ -52,7 +54,7 @@ main (int argc, char *argv [])
 	setlocale (LC_ALL, "");
 	bindtextdomain (GETTEXT_PACKAGE, GTOPLOCALEDIR);
 	textdomain (GETTEXT_PACKAGE);
-	
+
 	glibtop_init_r (&glibtop_global_server, 0, GLIBTOP_INIT_NO_OPEN);
 
 	glibtop_get_parameter (GLIBTOP_PARAM_METHOD, &method, sizeof (method));
@@ -75,7 +77,7 @@ main (int argc, char *argv [])
 
 	if (argc != 2)
 		glibtop_error ("Usage: %s interface", argv [0]);
-	
+
 	glibtop_get_netload (&netload, argv [1]);
 
 	addr.s_addr = netload.address;
