@@ -1,4 +1,4 @@
-/* $Id: procuid.h,v 1.25 2003/10/20 21:27:23 hadess Exp $ */
+/* $Id: procuid.h,v 1.26 2004/06/18 07:38:37 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -59,7 +59,7 @@ typedef struct _glibtop_proc_uid	glibtop_proc_uid;
 struct _glibtop_proc_uid
 {
 	guint64 flags;
-	int uid,		/* user id */
+	gint32 uid,		/* user id */
 		euid,		/* effective user id */
 		gid,		/* group id */
 		egid,		/* effective group id */
