@@ -1,4 +1,4 @@
-/* $Id: open.c,v 1.22 2004/07/17 12:01:24 bdejean Exp $ */
+/* $Id: open.c,v 1.23 2004/09/13 15:21:54 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -81,7 +81,7 @@ glibtop_open_s (glibtop *server, const char *program_name,
 			break;
 	}
 
-#if DEBUG
+#ifdef DEBUG
 	printf ("\nThis machine has %d CPUs.\n\n", server->ncpu);
 #endif
 }
